@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # -*- ruby encoding: utf-8 -*-
 
 require 'mime/types'
@@ -35,11 +37,20 @@ describe MIME::Types::Cache do
   describe '.load' do
     it 'does not use cache when RUBY_MIME_TYPES_CACHE is unset' do
       ENV.delete('RUBY_MIME_TYPES_CACHE')
-      assert_equal(nil, MIME::Types::Cache.load)
+      assert_nil MIME::Types::Cache.load
     end
 
     it 'does not use cache when missing' do
-      assert_equal(nil, MIME::Types::Cache.load)
+      assert_nil MIME::Types::Cache.load
+    end
+
+    it 'registers the data to be updated by #add_extensions' do
+      MIME::Types::Cache.save
+      reset_mime_types
+      assert_equal([], MIME::Types.type_for('foo.additional'))
+      html = MIME::Types['text/html'][0]
+      html.add_extensions('additional')
+      assert_equal([html], MIME::Types.type_for('foo.additional'))
     end
 
     it 'outputs an error when there is an invalid version' do
@@ -69,7 +80,7 @@ describe MIME::Types::Cache do
   describe '.save' do
     it 'does not create cache when RUBY_MIME_TYPES_CACHE is unset' do
       ENV.delete('RUBY_MIME_TYPES_CACHE')
-      assert_equal(nil, MIME::Types::Cache.save)
+      assert_nil MIME::Types::Cache.save
     end
 
     it 'creates the cache ' do
@@ -93,7 +104,7 @@ end
 describe MIME::Types::Container do
   it 'marshals and unmarshals correctly' do
     container = MIME::Types::Container.new
-    container['xyz'] << 'abc'
+    container.add('xyz', 'abc')
 
     # default proc should return Set[]
     assert_equal(Set[], container['abc'])
